.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.classify.padchest:

===========
 PAD-Chest
===========

* DataModule and support code: :py:mod:`.data.classify.padchest`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``padchest-idiap``
       - :py:mod:`.config.classify.data.padchest.idiap`
     * - ``padchest-tb-idiap``
       - :py:mod:`.config.classify.data.padchest.tb_idiap`
     * - ``padchest-no-tb-idiap``
       - :py:mod:`.config.classify.data.padchest.no_tb_idiap`
     * - ``padchest-cardiomegaly-idiap``
       - :py:mod:`.config.classify.data.padchest.cardiomegaly_idiap`
